android_d8_jar

Function android_d8_jar 

pub fn android_d8_jar(build_tools_version: Option<&str>) -> Option<PathBuf>
Returns the path to the d8.jar file for the given build tools version.

The path is determined by an ordered set of attempts:

  • The ANDROID_D8_JAR environment variable, if it is set and points to a file that exists.
  • The argument build_tools_version is used if it is Some, to find the subdirectory for the specific build tools version under the Android SDK build-tools directory.
  • The ANDROID_BUILD_TOOLS_VERSION environment variable is used to find the subdirectory for the build tools version under the Android SDK build-tools directory.
  • The highest Android build tools version found in the SDK build-tools directory is used if the build tools version is not set by the environment variable.