pub fn android_jar(platform_string: Option<&str>) -> Option<PathBuf>Expand description
Returns the path to the android.jar file for the given API level.
If the ANDROID_JAR environment variable is set and points to a file that exists,
that path is returned.
Otherwise, platform_string is used to find the android.jar file from the
platforms subdirectory in the Android SDK root directory.
If platform_string is None, the value of the following environment variables
are used to calculate the platform string:
ANDROID_PLATFORMANDROID_API_LEVELANDROID_SDK_VERSIONANDROID_SDK_EXTENSION