pub fn android_d8_jar(build_tools_version: Option<&str>) -> Option<PathBuf>Expand description
Returns the path to the d8.jar file for the given build tools version.
The path is determined by an ordered set of attempts:
- The
ANDROID_D8_JARenvironment variable, if it is set and points to a file that exists. - The argument
build_tools_versionis used if it isSome, to find the subdirectory for the specific build tools version under the Android SDKbuild-toolsdirectory. - The
ANDROID_BUILD_TOOLS_VERSIONenvironment variable is used to find the subdirectory for the build tools version under the Android SDKbuild-toolsdirectory. - The highest Android build tools version found in the SDK
build-toolsdirectory is used if the build tools version is not set by the environment variable.